diff --git a/buglist b/buglist
index 3a27e26..c9f9c40 100644
--- a/buglist
+++ b/buglist
@@ -159,6 +159,167 @@ and the problem exists for 11, 13, 14, 15, 17, 19 etc
    [19,1]  <-- not good
    [20,20]
 
+Subject: Re: [Q] radicalSolve fails to find all roots ?
+
+These are NOT bugs! But the following may be! Consider the equation 
+z^n==1 for n = 7:
+
+(1) -> radicalSolve(z^7=2)
+
+   (1)
+       7+-+      +---+7+-+    2%pi    7+-+    2%pi
+   [z= \|2 , z= \|- 1 \|2 sin(----) + \|2 cos(----),
+                                7               7
+        +---+7+-+    4%pi    7+-+    4%pi
+    z= \|- 1 \|2 sin(----) + \|2 cos(----),
+                       7               7
+        +---+7+-+    6%pi    7+-+    6%pi
+    z= \|- 1 \|2 sin(----) + \|2 cos(----),
+                       7               7
+        +---+7+-+    8%pi    7+-+    8%pi
+    z= \|- 1 \|2 sin(----) + \|2 cos(----),
+                       7               7
+        +---+7+-+    10%pi    7+-+    10%pi
+    z= \|- 1 \|2 sin(-----) + \|2 cos(-----),
+                       7                7
+        +---+7+-+    12%pi    7+-+    12%pi
+    z= \|- 1 \|2 sin(-----) + \|2 cos(-----)]
+                       7                7
+                     Type: List Equation Expression Integer
+
+-------------- comments
+
+Of course, these are correct solutions by Euler's Formula. A bit
+surprising that radicalSolve invokes these for z^7=2 and not for
+z^7=1; when n is 7, these trignometric values are not embeddable in a
+tower of "solvable" extensions. That is, these are not solutions
+expressible in terms of radicals (of *real* numbers) and arithmetic
+alone. Put another way, the regular 7-gon is not constructible by
+compass and ruler alone. From:
+
+http://mathworld.wolfram.com/ConstructiblePolygon.html
+http://mathworld.wolfram.com/TrigonometryAngles.html
+
+A necessary and sufficient condition that a regular n-gon be
+constructible is that phi(n) be a power of 2, where phi(n) is the
+totient function (Krzek 2001, p. 34).
+
+n =  1  2  3  4  5  6  7  8  9  10  11  12  13  14  15  16  17 18 19 20
+phi= 1  1  2  2  4  2  6  4  6   4  10   4  12   6   8   8  16  6 18  8
+bad=                   x     x       x       x   x              x  x
+Vladimir's "not good" values are =
+
+n =                    7            11      13  14  15      17    19
+
+So if you compare the constructible regular n-gons, you can see why
+Axiom's results are reasonable: radicalSolve only finds solutions that
+are expressible in terms of radicals and arithmetic operations. It did
+not find those for n = 15 and 17 probably (I am guessing) because at
+the time of implementation, these constructions were not known (at
+least to the programmer). On the other hand, for n = 9, 18, the
+solutions are expressible in radicals only if radicals of *complex*
+numbers are allowed and Axiom found those (perhaps it shouldn't?). The
+expansion for (-1)^(1/7) that Vladimir gave involves radicals of
+complex numbers, as theory predicts.
+
+
+When Axiom cannot find solutions, it is (presumably) a PROOF that the
+other solutions are NOT solvable by radicals (using *real* numbers),
+or at least, there is no known proof that it is solvable at the time
+of implementation=2E (That is why I am surprised at the above result
+for z^7=2).
+
+In other words, rather than viewing the answer for z^7=1 as a bug, we should
+view the answers for z^7=2, z^7=3 (and may be even z^9=1, z^18=1) as bugs!
+
+Still, the package should be upgraded.
+
+-------------------
+
+(1) -> radicalSolve(z^9=1,z)
+
+   (1)
+                                             +------------+
+                                             |   +---+
+        +------------+       +---+ +-+       |- \|- 3  - 1
+        |   +---+          (\|- 1 \|3  - 1) 3|------------
+        |- \|- 3  - 1                       \|      2
+   [z= 3|------------ , z= -------------------------------,
+       \|      2                          2
+                           +------------+
+                           |   +---+
+           +---+ +-+       |- \|- 3  - 1      +----------+
+       (- \|- 1 \|3  - 1) 3|------------      | +---+
+                          \|      2           |\|- 3  - 1
+    z= ---------------------------------, z= 3|---------- ,
+                       2                     \|     2
+                         +----------+                        +----------+=
+
+                         | +---+                             | +---+
+         +---+ +-+       |\|- 3  - 1         +---+ +-+       |\|- 3  - 1
+       (\|- 1 \|3  - 1) 3|----------     (- \|- 1 \|3  - 1) 3|----------
+                        \|     2                            \|     2
+    z= -----------------------------, z= ----------------------------=
+---,
+                     2                                  2
+          +---+          +---+
+       - \|- 3  - 1     \|- 3  - 1
+    z= ------------, z= ----------, z= 1]
+             2               2
+                      Type: List Equation Expression Integer
+                                       =
+
+(2) -> radicalSolve(z^7=3)
+
+   (2)
+       7+-+      +---+7+-+    2%pi    7+-+    2%pi
+   [z= \|3 , z= \|- 1 \|3 sin(----) + \|3 cos(----),
+                                7               7
+        +---+7+-+    4%pi    7+-+    4%pi
+    z= \|- 1 \|3 sin(----) + \|3 cos(----),
+                       7               7
+        +---+7+-+    6%pi    7+-+    6%pi
+    z= \|- 1 \|3 sin(----) + \|3 cos(----),
+                       7               7
+        +---+7+-+    8%pi    7+-+    8%pi
+    z= \|- 1 \|3 sin(----) + \|3 cos(----),
+                       7               7
+        +---+7+-+    10%pi    7+-+    10%pi
+    z= \|- 1 \|3 sin(-----) + \|3 cos(-----),
+                       7                7
+        +---+7+-+    12%pi    7+-+    12%pi
+    z= \|- 1 \|3 sin(-----) + \|3 cos(-----)]
+                       7                7
+                   Type: List Equation Expression Integer
+                                       =
+
+(3) -> radicalSolve(z^7=1.)
+                                                     7
+   WARNING (genufact): No known algorithm to factor ?  - 1.0
+     , trying square-free.
+
+   (3)
+                                       +-----+
+   [z= 1.0, z= 0.7818314824 6802980871\|- 1.0  + 0.6234898018 5873353=
+053,
+                               +-----+
+    z= 0.9749279121 8182360702\|- 1.0  - 0.2225209339 5631440428,
+                               +-----+
+    z= 0.4338837391 1755812048\|- 1.0  - 0.9009688679 0241912624,
+                                 +-----+
+    z= - 0.4338837391 1755812046\|- 1.0  - 0.9009688679 0241912625,
+                                 +-----+
+    z= - 0.9749279121 8182360702\|- 1.0  - 0.2225209339 563144043,
+                                 +-----+
+    z= - 0.7818314824 6802980872\|- 1.0  + 0.6234898018 5873353052]
+                   Type: List Equation Expression Float
+                                                   =
+
+(4) -> radicalSolve(z^6+z^5+z^4+z^3+z^2+z+1=0)
+
+   (4)  []
+                  Type: List Equation Expression Integer
+
 =========================================================================
 bug 7248: differentiation bug in D(1,z)
 
diff --git a/changelog b/changelog
index 186f782..cbdc3d6 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20140613 tpd src/axiom-website/patches.html 20140613.13.tpd.patch
+20140613 tpd buglist bug 7249: radicalSolve(z^7=1, z) update
 20140613 tpd src/axiom-website/patches.html 20140613.12.tpd.patch
 20140613 tpd buglist bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
 20140613 tpd src/axiom-website/patches.html 20140613.11.tpd.patch
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 5507487..03c5f10 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4444,6 +4444,8 @@ buglist bug 7072/19 D(0^z, z) closed
 buglist bug 7250: print(typeOf(1)::OutputForm) Value Stack Overflow
 <a href="patches/20140613.12.tpd.patch">20140613.12.tpd.patch</a>
 buglist bug 7251: integrate(1/(1+z^4), z=0..1) :: Complex Float
+<a href="patches/20140613.13.tpd.patch">20140613.13.tpd.patch</a>
+buglist bug 7249: radicalSolve(z^7=1, z) update
  </body>
 </html>
 
